DsCustomMiddleWareRequest class

Constructors

DsCustomMiddleWareRequest(String method, Uri uri, Map<String, String> headers, dynamic body)

Properties

body → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
final

Methods

change({Map<String, String>? headers}) DsCustomMiddleWareRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited