DsCustomMiddleWareResponse class

Constructors

DsCustomMiddleWareResponse(int statusCode, Map<String, String> headers, dynamic body, {DsCustomMiddleWareRequest? request})

Properties

body → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
request DsCustomMiddleWareRequest?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

copyWith({int? statusCode, Map<String, String>? headers, dynamic body, DsCustomMiddleWareRequest? request}) DsCustomMiddleWareResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited